Attio.Comments (Attio v0.2.0)

Copy Markdown View Source

Functions for managing individual comments.

Comments belong to threads, which are attached to records or list entries. Use Attio.Threads to create a new thread with an initial comment.

Requires the comment:read scope for read operations and comment:read-write for mutations.

Summary

Functions

Deletes a comment.

Gets a single comment by its ID.

Updates a comment's content.

Functions

delete(client, comment_id)

@spec delete(Attio.Client.t(), String.t()) :: {:ok, map()} | {:error, term()}

Deletes a comment.

get(client, comment_id)

@spec get(Attio.Client.t(), String.t()) :: {:ok, map()} | {:error, term()}

Gets a single comment by its ID.

update(client, comment_id, attrs)

@spec update(Attio.Client.t(), String.t(), map()) :: {:ok, map()} | {:error, term()}

Updates a comment's content.