Functions for managing Attio lists.
Lists are process models that contain entries — records of a single object type enriched with list-specific attributes (e.g. pipeline stage, owner).
Requires the list_configuration:read scope for read operations and
list_configuration:read-write for mutations.
Summary
Functions
Creates a new list.
Gets a single list by its ID or slug.
Lists all lists in the workspace.
Lists saved views for a list.
Updates a list's configuration.
Functions
@spec create(Attio.Client.t(), map()) :: {:ok, map()} | {:error, term()}
Creates a new list.
Required attributes
"title"- Display name for the list."object_slug"- The slug of the object type this list tracks (e.g."people").
@spec get(Attio.Client.t(), String.t()) :: {:ok, map()} | {:error, term()}
Gets a single list by its ID or slug.
@spec list(Attio.Client.t()) :: {:ok, map()} | {:error, term()}
Lists all lists in the workspace.
@spec list_views(Attio.Client.t(), String.t()) :: {:ok, map()} | {:error, term()}
Lists saved views for a list.
@spec update(Attio.Client.t(), String.t(), map()) :: {:ok, map()} | {:error, term()}
Updates a list's configuration.